@@ -17,11 +17,11 @@ Artifactory::Client - Perl client for Artifactory REST API
 
 =head1 VERSION
 
-Version 0.1.15
+Version 0.1.18
 
 =cut
 
-our $VERSION = '0.1.15';
+our $VERSION = '0.1.18';
 
 =head1 SYNOPSIS
 
@@ -69,7 +69,6 @@ version of my functional tests.  They should serve as a detailed guide on how to
 has 'artifactory' => (
     is => 'ro',
     isa => 'Str',
-    required => 1
 );
 
 has 'port' => (
@@ -87,7 +86,6 @@ has 'ua' => (
 has 'repository' => (
     is => 'ro',
     isa => 'Str',
-    required => 1
 );
 
 =head1 GENERIC METHODS
@@ -138,6 +136,17 @@ sub delete {
     return $self->_request( 'delete', @args );
 }
 
+=head2 request( @args )
+
+Invokes request() on LWP::UserAgent-like object; params are passed through.
+
+=cut
+
+sub request {
+    my ( $self, @args ) = @_;
+    return $self->_request( 'request', @args );
+}
+
 =head1 BUILDS
 
 =cut
@@ -583,19 +592,6 @@ sub move_item {
     return $self->_handle_item( %args );
 }
 
-=head2 get_repository_replication_configuration
-
-Returns repository's replication configuration
-
-=cut
-
-sub get_repository_replication_configuration {
-    my $self = shift;
-    my ( $artifactory, $port, $repository ) = $self->_unpack_attributes( 'artifactory', 'port', 'repository' );
-    my $url = "$artifactory:$port/artifactory/api/replication/$repository";
-    return $self->get( $url );
-}
-
 sub _build_ua {
     my $self = shift;
     $self->{ ua } = LWP::UserAgent->new() unless( $self->{ ua } );
